==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebActiveStepChangingArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangingArgsDetailDescription } from "./WebActiveStepChangingArgsDetailDescription";
/**
 * @hidden
 */
export let WebActiveStepChangingArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveStepChangingArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveStepChangingArgsDetailDescriptionMetadata.a == null) {
                WebActiveStepChangingArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveStepChangingArgsDetailDescriptionMetadata.c(WebActiveStepChangingArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebActiveStepChangingArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebActiveStepChangingArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveStepChangingArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("OldIndex", "Number:double");
            a.item("NewIndex", "Number:double");
        }
        static d(a) {
            WebActiveStepChangingArgsDetailDescriptionMetadata.b(a);
            a.ad("WebActiveStepChangingArgsDetail", () => new WebActiveStepChangingArgsDetailDescription());
            a.ac("WebActiveStepChangingArgsDetail", WebActiveStepChangingArgsDetailDescriptionMetadata.a);
        }
    }
    WebActiveStepChangingArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveStepChangingArgsDetailDescriptionMetadata, 'WebActiveStepChangingArgsDetailDescriptionMetadata');
    WebActiveStepChangingArgsDetailDescriptionMetadata.a = null;
    return WebActiveStepChangingArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebActiveStepChangingArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangingArgsDetailDescription } from "./WebActiveStepChangingArgsDetailDescription";
/**
 * @hidden
 */
export let WebActiveStepChangingArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveStepChangingArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveStepChangingArgsDetailDescriptionMetadata.a == null) {
                WebActiveStepChangingArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveStepChangingArgsDetailDescriptionMetadata.c(WebActiveStepChangingArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebActiveStepChangingArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebActiveStepChangingArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveStepChangingArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("OldIndex", "Number:double");
            a.item("NewIndex", "Number:double");
        }
        static d(a) {
            WebActiveStepChangingArgsDetailDescriptionMetadata.b(a);
            a.ae("WebActiveStepChangingArgsDetail", () => new WebActiveStepChangingArgsDetailDescription());
            a.ad("WebActiveStepChangingArgsDetail", WebActiveStepChangingArgsDetailDescriptionMetadata.a);
        }
    }
    WebActiveStepChangingArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveStepChangingArgsDetailDescriptionMetadata, 'WebActiveStepChangingArgsDetailDescriptionMetadata');
    WebActiveStepChangingArgsDetailDescriptionMetadata.a = null;
    return WebActiveStepChangingArgsDetailDescriptionMetadata;
})();
